using CookComputing.XmlRpc;
using System.IO;

//We use the XMLRPC library from
// xml-rpc.net


class UniversignSign
{
    private string email;
    private string password;

    public UniversignSign(string email, string password)
    {
        this.email = email;
        this.password = password;
    }

    private ISignature init()
    {
        //Initialize the proxy
        ISignature proxy = (ISignature)XmlRpcProxyGen.Create(typeof(ISignature));
        proxy.Url = "https://ws.universign.eu/sign/rpc";
        //set credentials
        proxy.Credentials = new System.Net.NetworkCredential(email, password);
        //The library fails if set to True
        proxy.KeepAlive = false;

        return proxy;
    }

    public byte[] sign(byte[] document)
    {
         try {
             ISignature proxy = init();
             return proxy.sign(document);
         } catch (System.Exception ex) {
             System.Console.WriteLine(ex.ToString());
             throw ex;
         }
    }

    public byte[] signWithOptions(byte[] document)
    {
         ISignature proxy = init();
         SignOptions options = new SignOptions();
         options.profile = "default";
         SignatureField sf = new SignatureField();
         sf.page = 1;
         sf.x = 100;
         sf.y = 100;
         options.signatureField = sf;
         options.reason = "Reason to sign the document.";
         options.location = "Location of the signer.";
         options.signatureFormat = "PADES";
         try {
             return proxy.sign(document, options);
         } catch (System.Exception ex) {
             System.Console.WriteLine(ex.ToString());
             throw ex;
         }
    } 


    static void Main(string[] args)
    {
        UniversignSign univ = new UniversignSign("email", "password");
        byte[] document = File.ReadAllBytes("contract.pdf");
        byte[] signed = univ.sign(document);
        File.WriteAllBytes("signed.pdf", signed);
    }
}
